@@ -1,7 +1,7 @@
 """
 Type annotations for imagebuilder service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/type_defs/)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_imagebuilder/type_defs.html)
 
 Usage::
 
@@ -14,8 +14,6 @@ Usage::
 import sys
 from typing import Dict, List, Mapping, Sequence
 
-from typing_extensions import NotRequired
-
 from .literals import (
     ComponentTypeType,
     EbsVolumeTypeType,
@@ -1337,6 +1335,8 @@ LaunchPermissionConfigurationTypeDef = TypedDict(
     {
         "userIds": Sequence[str],
         "userGroups": Sequence[str],
+        "organizationArns": Sequence[str],
+        "organizationalUnitArns": Sequence[str],
     },
     total=False,
 )
